pub struct StaticAccessControl { /* private fields */ }Expand description
Static AccessControlPort backed by a list of ChannelAccessPolicy.
Empty allow_from on a policy means “allow all” (default open).
Unknown channels fall back to the default policy (allow all).
Implementations
Sourceimpl StaticAccessControl
impl StaticAccessControl
Sourcepub fn new(policies: Vec<ChannelAccessPolicy>) -> Self
pub fn new(policies: Vec<ChannelAccessPolicy>) -> Self
Create a new instance from a list of channel policies.